package cn.com.poc.thirdparty.resource.demand.ai.function.text_in_pdf2md.api;

/**
 * @author alex.yao
 * @date 2025/5/7
 */

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;

public class OCRClient {

    private Logger logger = LoggerFactory.getLogger(OCRClient.class);
    private final String appId = "dafd04a574230c00ccba61132160de0c";
    private final String secretCode = "3bc03c7e6f9402963e6e71d16d786a9c";
    private final String baseUrl = "https://api.textin.com/ai/service/v1/pdf_to_markdown";
    public OCRClient() {
    }

    public String recognize(byte[] fileContent, HashMap<String, Object> options) throws IOException {
        StringBuilder queryParams = new StringBuilder();
        for (Map.Entry<String, Object> entry : options.entrySet()) {
            if (queryParams.length() > 0) {
                queryParams.append("&");
            }
            queryParams.append(URLEncoder.encode(entry.getKey(), "UTF-8"))
                    .append("=")
                    .append(URLEncoder.encode(entry.getValue().toString(), "UTF-8"));
        }

        String fullUrl = baseUrl + (queryParams.length() > 0 ? "?" + queryParams : "");
        URL url = new URL(fullUrl);

        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setRequestMethod("POST");
        connection.setRequestProperty("x-ti-app-id", appId);
        connection.setRequestProperty("x-ti-secret-code", secretCode);
        connection.setRequestProperty("Content-Type", "text/plain");
        connection.setDoOutput(true);
        try (OutputStream os = connection.getOutputStream()) {
            os.write(fileContent);
            os.flush();
        }

        int responseCode = connection.getResponseCode();
        if (responseCode == HttpURLConnection.HTTP_OK) {
            try (BufferedReader in = new BufferedReader(
                    new InputStreamReader(connection.getInputStream()))) {
                StringBuilder response = new StringBuilder();
                String inputLine;
                while ((inputLine = in.readLine()) != null) {
                    response.append(inputLine);
                }
                return response.toString();
            }
        } else {
            logger.error("HTTP request failed with code: {}, Error message view :{}", responseCode, "https://www.textin.com/document/pdf_to_markdown");
            throw new IOException("HTTP request failed with code: " + responseCode);
        }
    }

}